@@ -210,6 +210,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateCosRecharge(self, request):
+        """本接口用于创建cos导入任务
+
+        :param request: Request instance for CreateCosRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateCosRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateCosRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCosRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCosRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateExport(self, request):
         """本接口仅创建下载任务，任务返回的下载地址，请用户调用DescribeExports查看任务列表。其中有下载地址CosPath参数。参考文档https://cloud.tencent.com/document/product/614/56449
 
@@ -303,7 +326,7 @@ class ClsClient(AbstractClient):
 
 
     def CreateShipper(self, request):
-        """创建新的投递规则，【！！！注意】使用此接口，需要检查是否配置了投递COS的角色和权限。如果没有配置，请参考文档投递权限查看和配置https://cloud.tencent.com/document/product/614/71623。
+        """新建投递到COS的任务，【！！！注意】使用此接口，需要检查是否配置了投递COS的角色和权限。如果没有配置，请参考文档投递权限查看和配置https://cloud.tencent.com/document/product/614/71623。
 
         :param request: Request instance for CreateShipper.
         :type request: :class:`tencentcloud.cls.v20201016.models.CreateShipperRequest`
@@ -602,7 +625,7 @@ class ClsClient(AbstractClient):
 
 
     def DeleteShipper(self, request):
-        """删除投递规则
+        """删除投递COS任务
 
         :param request: Request instance for DeleteShipper.
         :type request: :class:`tencentcloud.cls.v20201016.models.DeleteShipperRequest`
@@ -693,6 +716,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAlertRecordHistory(self, request):
+        """获取告警历史，例如今天未恢复的告警
+
+        :param request: Request instance for DescribeAlertRecordHistory.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAlertRecordHistoryRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAlertRecordHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAlertRecordHistory", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAlertRecordHistoryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeConfigExtras(self, request):
         """本接口用于获取特殊采集配置，特殊采集配置应用于自建K8S环境的采集Agent
 
@@ -785,6 +831,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCosRecharges(self, request):
+        """本接口用于获取cos导入配置
+
+        :param request: Request instance for DescribeCosRecharges.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeCosRechargesRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeCosRechargesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCosRecharges", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCosRechargesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExports(self, request):
         """本接口用于获取日志下载任务列表
 
@@ -1016,7 +1085,7 @@ class ClsClient(AbstractClient):
 
 
     def DescribeShippers(self, request):
-        """获取投递规则信息列表
+        """获取投递到COS的任务配置信息
 
         :param request: Request instance for DescribeShippers.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeShippersRequest`
@@ -1222,6 +1291,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyCosRecharge(self, request):
+        """本接口用于修改cos导入任务
+
+        :param request: Request instance for ModifyCosRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyCosRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyCosRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyCosRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyCosRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyIndex(self, request):
         """本接口用于修改索引配置，该接口除受默认接口请求频率限制外，针对单个日志主题，并发数不能超过1，即同一时间同一个日志主题只能有一个正在执行的索引配置修改操作。
 
@@ -1431,11 +1523,11 @@ class ClsClient(AbstractClient):
 
     def UploadLog(self, request, body):
         """## 提示
-        为了保障您日志数据的可靠性以及更高效地使用日志服务，建议您使用CLS优化后的接口[上传结构化日志](https://cloud.tencent.com/document/product/614/16873)上传日志。
+        为了保障您日志数据的可靠性以及更高效地使用日志服务，建议您使用CLS优化后的接口[上传结构化日志](https://cloud.tencent.com/document/product/614/16873)。
 
         同时我们给此接口专门优化定制了多个语言版本的SDK供您选择，SDK提供统一的异步发送、资源控制、自动重试、优雅关闭、感知上报等功能，使上报日志功能更完善，详情请参考[SDK采集](https://cloud.tencent.com/document/product/614/67157)。
 
-        同时云API上传日志接口也支持同步上传日志数据，如果您选继续使用此接口请参考下文。
+        同时云API上传日志接口也支持同步上传日志数据，如果您选择继续使用此接口请参考下文。
 
         ## 功能描述
 
